#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === Wetter::GUI::Gtk::Main
# =========================================================================== #
require 'gtk_module'
require 'wetter/wetter.rb'

class Wetter

module GUI

module Gtk

class Main < ::Gtk::VBox # === Wetter::GUI::Gtk::Main

  include ::Gtk::BaseModule

  ::Gtk::Settings.default.gtk_font_name = 'Mono'

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      run_already = true
    )
    super()
    set_font_size(:larger)
    reset
    create_main_label
    connect_skeleton
    run if run_already
  end

  # ========================================================================= #
  # === connect_skeleton
  # ========================================================================= #
  def connect_skeleton
    pack_start(gtk_label('Current temperature in Vienna:'), true, true, 2)
    pack_start(@label_showing_the_temperature, true, true, 2)
  end

  # ========================================================================= #
  # === create_main_label
  # ========================================================================= #
  def create_main_label
    @label_showing_the_temperature = gtk_label
    @label_showing_the_temperature.make_bold
  end

  # ========================================================================= #
  # === reset
  # ========================================================================= #
  def reset
    @temperature = ::Wetter.temperature?
  end

  # ========================================================================= #
  # === attach_temperature_value_to_the_main_label
  # ========================================================================= #
  def attach_temperature_value_to_the_main_label
    @label_showing_the_temperature.set_text(@temperature.to_s)
  end

  # ========================================================================= #
  # === run
  # ========================================================================= #
  def run
    attach_temperature_value_to_the_main_label
    show_all
  end

end

end; end; end

if __FILE__ == $PROGRAM_NAME
  x = Wetter::GUI::Gtk::Main.new
  r = Gtk.run('50%','40%',
    icon: '/Users/x/DATA/IMG/PC/TABBLE/TABBLE.png',
    title: 'Wetter',
    padding: 4
  )
  r.add(x)
  r.show_all
  r.add_shortcut(1, 'focus(:left)', :alt)
  r.run
end